## ibek/tests/samples/schemas

The files in this folder represent schemas as described in the following table.

When changes have been
made these will need regenerating in order for the tests to pass.

It is important to review the generated files since the tests will always pass
after regeneration is done even if the output is badly broken.

Run ../generate_samples.sh to regenerate them